# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-04 09:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('currency_history', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='currency',
            options={'ordering': ['iso_code'], 'verbose_name': 'Currency', 'verbose_name_plural': 'Currencies'},
        ),
        migrations.AlterModelOptions(
            name='currencyrate',
            options={'ordering': ['from_currency__iso_code', 'to_currency__iso_code'], 'verbose_name': 'Currency rate', 'verbose_name_plural': 'Currency rates'},
        ),
        migrations.AlterModelOptions(
            name='currencyratehistory',
            options={'ordering': ['-date', 'rate__to_currency__iso_code'], 'verbose_name': 'Currency rate history', 'verbose_name_plural': 'Currency rate history'},
        ),
    ]
