{% load i18n %}
<h1>{% trans "Currency exchange email report" %}</h1>
<p>{% trans "Your rates has just been updated:" %}</p>

<table>
    <tr>
        <th>{% trans "From" %}</th>
        <th>{% trans "To" %}</th>
        <th>{% trans "Date" %}</th>
        <th>{% trans "Value" %}</th>
        <th>{% trans "Trackey by" %}</th>
    </tr>
    {% for rate in rates %}
        {% with rate.latest as history %}
            <tr>
                <td>{{ rate.from_currency }}</td>
                <td>{{ rate.to_currency }}</td>
                <td>{{ history.date }}</td>
                <td>{{ history.value }}</td>
                <td>{{ history.tracked_by }}</td>
            </tr>
        {% endwith %}
    {% endfor %}
</table>